import { Host, h } from "@stencil/core";
import { IGC_DEFAULT_PANE_SIZE } from "../dockmanager.interfaces";
import { IgcSplitPaneOrientation } from "../dockmanager.public-interfaces";
/**
 * @hidden
 */
export class IgcSplitPaneComponent {
  constructor() {
    this.orientation = undefined;
    this.size = undefined;
    this.useFixedSize = false;
    this.parentUseFixedSize = false;
  }
  componentDidRender() {
    this.rendered.emit();
  }
  render() {
    const size = this.size || this.size === 0 ? this.size : IGC_DEFAULT_PANE_SIZE;
    return (h(Host, { role: "group", style: {
        flexDirection: this.orientation === IgcSplitPaneOrientation.horizontal ? 'row' : 'column',
        flex: this.parentUseFixedSize ? `0 0 ${size}px` : `${size} 1 ${size}px`
      }, part: "split-pane" }));
  }
  static get is() { return "igc-split-pane-component"; }
  static get encapsulation() { return "scoped"; }
  static get originalStyleUrls() {
    return {
      "$": ["split-pane-component.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["split-pane-component.css"]
    };
  }
  static get properties() {
    return {
      "orientation": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "IgcSplitPaneOrientation",
          "resolved": "IgcSplitPaneOrientation.horizontal | IgcSplitPaneOrientation.vertical",
          "references": {
            "IgcSplitPaneOrientation": {
              "location": "import",
              "path": "../dockmanager.public-interfaces",
              "id": "src/components/dockmanager/dockmanager.public-interfaces.ts::IgcSplitPaneOrientation"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "orientation",
        "reflect": false
      },
      "size": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "size",
        "reflect": false
      },
      "useFixedSize": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "use-fixed-size",
        "reflect": false,
        "defaultValue": "false"
      },
      "parentUseFixedSize": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "parent-use-fixed-size",
        "reflect": false,
        "defaultValue": "false"
      }
    };
  }
  static get events() {
    return [{
        "method": "rendered",
        "name": "rendered",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "complexType": {
          "original": "HTMLIgcSplitPaneComponentElement",
          "resolved": "HTMLIgcSplitPaneComponentElement",
          "references": {
            "HTMLIgcSplitPaneComponentElement": {
              "location": "global",
              "id": "global::HTMLIgcSplitPaneComponentElement"
            }
          }
        }
      }];
  }
}
//# sourceMappingURL=split-pane-component.js.map
