import { Host, h } from "@stencil/core";
import { addResourceStrings } from "../..";
import { IgcDockManagerPaneType, IgcDockingIndicatorPosition, IgcPaneDragActionType, IgcSplitPaneOrientation, IgcUnpinnedLocation } from "../dockmanager/dockmanager.public-interfaces";
/**
 * @hidden
 */
const customResourceStrings = {
  close: '[Custom]Close',
  pin: '[Custom]Pin',
  unpin: '[Custom]Unpin',
  maximize: '[Custom]Maximize',
  minimize: '[Custom]Minimize',
  moreOptions: '[Custom]More options'
};
addResourceStrings('custom', customResourceStrings);
/**
 * @hidden
 */
export class SampleComponent {
  constructor() {
    this.teamExplorerPane = {
      type: IgcDockManagerPaneType.contentPane,
      header: 'Team Explorer',
      contentId: 'content7',
      allowMaximize: true
    };
    this.unpinnedToolboxPane = {
      type: IgcDockManagerPaneType.contentPane,
      header: 'Toolbox',
      contentId: 'content1',
      isPinned: false,
      unpinnedHeaderId: "toolboxHeader"
    };
    this.unpinnedTeamExplorerPane = {
      type: IgcDockManagerPaneType.contentPane,
      header: 'Team Explorer',
      contentId: 'content14',
      isPinned: false,
      unpinnedHeaderId: "teamExplorerHeader"
    };
    this.layout1 = {
      rootPane: {
        type: IgcDockManagerPaneType.splitPane,
        orientation: IgcSplitPaneOrientation.horizontal,
        panes: [
          this.unpinnedToolboxPane,
          this.unpinnedTeamExplorerPane,
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            size: 300,
            panes: [
              {
                type: IgcDockManagerPaneType.documentHost,
                size: 300,
                rootPane: {
                  type: IgcDockManagerPaneType.splitPane,
                  orientation: IgcSplitPaneOrientation.horizontal,
                  allowEmpty: true,
                  panes: [
                    {
                      type: IgcDockManagerPaneType.tabGroupPane,
                      panes: [
                        {
                          type: IgcDockManagerPaneType.contentPane,
                          header: 'MainWindow.xaml',
                          contentId: 'content2',
                          documentOnly: true,
                          // allowMaximize: false,
                        },
                        {
                          type: IgcDockManagerPaneType.contentPane,
                          header: 'MainWindow.xaml.cs',
                          contentId: 'content6',
                          documentOnly: true,
                          allowFloating: false
                        }
                      ]
                    },
                    {
                      type: IgcDockManagerPaneType.contentPane,
                      header: 'App.xaml',
                      contentId: 'content8',
                      allowMaximize: true,
                      acceptsInnerDock: false
                    }
                  ]
                }
              },
              {
                type: IgcDockManagerPaneType.splitPane,
                orientation: IgcSplitPaneOrientation.horizontal,
                allowEmpty: true,
                panes: []
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                header: 'Error List',
                contentId: 'content3',
                allowDocking: false,
                allowFloating: false,
                allowMaximize: false
              }
            ]
          },
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            panes: [
              {
                type: IgcDockManagerPaneType.tabGroupPane,
                size: 200,
                allowEmpty: true,
                panes: [
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    header: 'Solution Explorer',
                    headerId: 'header1',
                    tabHeaderId: 'tabHeader1',
                    unpinnedHeaderId: 'unpinnedHeader1',
                    contentId: 'content4',
                    allowMaximize: false
                  },
                  this.teamExplorerPane
                ]
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                header: 'Properties',
                contentId: 'content5',
                unpinnedLocation: IgcUnpinnedLocation.top,
                allowFloating: false,
                allowMaximize: false
              }
            ]
          }
        ]
      },
      floatingPanes: [
        {
          type: IgcDockManagerPaneType.splitPane,
          orientation: IgcSplitPaneOrientation.horizontal,
          floatingLocation: { x: 50, y: 100 },
          floatingWidth: 200,
          floatingHeight: 100,
          panes: [
            {
              type: IgcDockManagerPaneType.contentPane,
              header: 'Notifications',
              contentId: 'content9',
              allowDocking: false
            }
          ],
          // floatingResizable: true
        },
        {
          type: IgcDockManagerPaneType.splitPane,
          allowEmpty: true,
          orientation: IgcSplitPaneOrientation.horizontal,
          floatingLocation: { x: 250, y: 350 },
          floatingWidth: 300,
          floatingHeight: 200,
          panes: [
            {
              type: IgcDockManagerPaneType.contentPane,
              header: 'Floating 1',
              contentId: 'content10',
              acceptsInnerDock: false
            },
            {
              type: IgcDockManagerPaneType.contentPane,
              header: 'Floating 2',
              contentId: 'content11',
              allowMaximize: false
            }
          ]
        },
        {
          type: IgcDockManagerPaneType.splitPane,
          orientation: IgcSplitPaneOrientation.horizontal,
          floatingLocation: { x: 750, y: 200 },
          floatingWidth: 300,
          floatingHeight: 200,
          panes: [
            {
              type: IgcDockManagerPaneType.tabGroupPane,
              allowEmpty: true,
              panes: [
                {
                  type: IgcDockManagerPaneType.contentPane,
                  header: 'Floating Tab 1',
                  contentId: 'content12'
                },
                {
                  type: IgcDockManagerPaneType.contentPane,
                  header: 'Floating Tab 2',
                  contentId: 'content13'
                }
              ]
            }
          ]
        }
      ]
    };
    this.layout2 = {
      rootPane: {
        type: IgcDockManagerPaneType.splitPane,
        orientation: IgcSplitPaneOrientation.horizontal,
        panes: [
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            panes: [
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content1',
                header: 'Content Pane 1'
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content2',
                header: 'Unpinned Pane 1',
                isPinned: false
              }
            ]
          },
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            size: 200,
            panes: [
              {
                type: IgcDockManagerPaneType.documentHost,
                size: 200,
                rootPane: {
                  type: IgcDockManagerPaneType.splitPane,
                  orientation: IgcSplitPaneOrientation.horizontal,
                  panes: [
                    {
                      type: IgcDockManagerPaneType.tabGroupPane,
                      panes: [
                        {
                          type: IgcDockManagerPaneType.contentPane,
                          header: 'Document 1',
                          contentId: 'content3'
                        },
                        {
                          type: IgcDockManagerPaneType.contentPane,
                          header: 'Document 2',
                          contentId: 'content4'
                        }
                      ]
                    }
                  ]
                }
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content5',
                header: 'Unpinned Pane 2',
                isPinned: false
              }
            ]
          },
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            panes: [
              {
                type: IgcDockManagerPaneType.tabGroupPane,
                size: 200,
                // selectedIndex: 1,
                panes: [
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    contentId: 'content6',
                    header: 'Tab 1'
                  },
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    contentId: 'content7',
                    header: 'Tab 2'
                  },
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    contentId: 'content8',
                    header: 'Tab 3'
                  },
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    contentId: 'content9',
                    header: 'Tab 4'
                  },
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    contentId: 'content10',
                    header: 'Tab 5'
                  }
                ]
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content11',
                header: 'Content Pane 2'
              }
            ]
          }
        ]
      },
      floatingPanes: [
        {
          type: IgcDockManagerPaneType.splitPane,
          orientation: IgcSplitPaneOrientation.horizontal,
          floatingHeight: 150,
          floatingWidth: 250,
          floatingLocation: { x: 300, y: 200 },
          panes: [
            {
              type: IgcDockManagerPaneType.contentPane,
              contentId: 'content12',
              header: 'Floating Pane'
            }
          ]
        }
      ]
    };
    this.layout3 = {
      rootPane: {
        type: IgcDockManagerPaneType.splitPane,
        orientation: IgcSplitPaneOrientation.horizontal,
        useFixedSize: true,
        panes: [
          // {
          //   type: IgcDockManagerPaneType.splitPane,
          //   useFixedSize: true,
          //   orientation: IgcSplitPaneOrientation.vertical,
          //   size: 300, // PIXELS
          //   panes: [
          //     {
          //       type: IgcDockManagerPaneType.contentPane,
          //       contentId: 'content1',
          //       header: 'Content Pane 1',
          //       size: 500 // PIXELS
          //     },
          //     {
          //       type: IgcDockManagerPaneType.contentPane,
          //       contentId: 'content2',
          //       header: 'Content Pane 2',
          //       size: 300 // PIXELS
          //     }
          //   ]
          // },
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            size: 450,
            panes: [
              {
                type: IgcDockManagerPaneType.splitPane,
                orientation: IgcSplitPaneOrientation.horizontal,
                useFixedSize: true,
                size: 300,
                panes: [
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    contentId: 'content4',
                    header: 'Content Pane 4',
                    size: 400 // PIXELS
                  }
                ]
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content7',
                header: 'Content Pane 7',
                size: 450 // PIXELS
              }
            ]
          }
        ]
      },
      floatingPanes: [
      // {
      //   type: IgcDockManagerPaneType.splitPane,
      //   orientation: IgcSplitPaneOrientation.vertical,
      //   useFixedSize: true,
      //   // size: 950, // PIXELS
      //   floatingHeight: 950,
      //   floatingWidth: 650,
      //   floatingLocation: { x: 200, y: 50 },
      //   panes: [
      //     {
      //       type: IgcDockManagerPaneType.splitPane,
      //       orientation: IgcSplitPaneOrientation.horizontal,
      //       useFixedSize: true,
      //       size: 400, // PIXELS
      //       panes: [
      //         {
      //           type: IgcDockManagerPaneType.contentPane,
      //           contentId: 'content12',
      //           header: 'Content Pane 12',
      //           size: 400 // PIXELS
      //         },
      //         {
      //           type: IgcDockManagerPaneType.contentPane,
      //           contentId: 'content13',
      //           header: 'Content Pane 13',
      //           size: 200 // PIXELS
      //         }
      //       ]
      //     },
      //     {
      //       type: IgcDockManagerPaneType.splitPane,
      //       orientation: IgcSplitPaneOrientation.vertical,
      //       useFixedSize: true,
      //       size: 500, // PIXELS
      //       panes: [
      //         {
      //           type: IgcDockManagerPaneType.contentPane,
      //           contentId: 'content11',
      //           header: 'Content Pane 11',
      //           size: 300 // PIXELS
      //         },
      //       ]
      //     }
      //   ]
      // }
      ]
    };
    this.commonProps = {
      allowClose: false,
      allowMaximize: false,
      allowPinning: false,
    };
    this.bodyRect = document.body.getBoundingClientRect();
    this.bodyWidth = this.bodyRect.width - 36;
    this.bodyHeight = this.bodyRect.height - 36;
    this.layout4 = {
      rootPane: {
        type: IgcDockManagerPaneType.splitPane,
        orientation: IgcSplitPaneOrientation.vertical,
        useFixedSize: true,
        panes: [
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            useFixedSize: true,
            size: this.bodyHeight / 2,
            panes: [
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content1',
                header: 'Content 1 Header',
                size: 260, // PIXELS
              },
              {
                type: IgcDockManagerPaneType.splitPane,
                orientation: IgcSplitPaneOrientation.horizontal,
                size: 240 + 10,
                useFixedSize: true,
                panes: [
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: this.bodyWidth / 3,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content2',
                        header: 'Content 2 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    useFixedSize: true,
                    size: (this.bodyWidth * 2) / 3,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content3',
                        header: 'Content 3 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  // {
                  //   type: IgcDockManagerPaneType.contentPane,
                  //   contentId: 'content_not_used_2',
                  //   header: 'NOT USED',
                  //   // size: 0,
                  //   ...this.commonProps,
                  // },
                ],
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content4',
                header: 'Content 4 Header',
                size: 290, // PIXELS
              },
              {
                type: IgcDockManagerPaneType.splitPane,
                orientation: IgcSplitPaneOrientation.horizontal,
                size: 240 + 10,
                panes: [
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: this.bodyWidth / 3,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content5',
                        header: 'Content 5 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: (this.bodyWidth * 2) / 3,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content6',
                        header: 'Content 6 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  // {
                  //   type: IgcDockManagerPaneType.contentPane,
                  //   contentId: 'content_not_used_3',
                  //   header: 'NOT USED',
                  //   ...this.commonProps,
                  // },
                ],
              },
              {
                type: IgcDockManagerPaneType.splitPane,
                orientation: IgcSplitPaneOrientation.horizontal,
                size: 240 + 10,
                panes: [
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: this.bodyWidth / 2,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content7',
                        header: 'Content 7 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: this.bodyWidth / 2,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content8',
                        header: 'Content 8 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  // {
                  //   type: IgcDockManagerPaneType.contentPane,
                  //   contentId: 'content_not_used_4',
                  //   header: 'NOT USED',
                  //   ...this.commonProps,
                  // },
                ],
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content9',
                header: 'Content 9 Header',
                size: 290, // PIXELS
              },
              // {
              //   type: IgcDockManagerPaneType.contentPane,
              //   contentId: 'content_not_used_1',
              //   header: 'NOT USED',
              //   ...this.commonProps,
              // },
            ],
          },
        ],
      },
      floatingPanes: [],
    };
    this.layout5 = {
      rootPane: {
        type: IgcDockManagerPaneType.splitPane,
        orientation: IgcSplitPaneOrientation.horizontal,
        panes: [
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            useFixedSize: true,
            size: this.bodyWidth,
            panes: [
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content1',
                header: 'Content 1 Header',
                size: 60, // PIXELS
              },
              {
                type: IgcDockManagerPaneType.splitPane,
                orientation: IgcSplitPaneOrientation.horizontal,
                size: 240 + 10,
                useFixedSize: true,
                panes: [
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: this.bodyWidth / 3,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content2',
                        header: 'Content 2 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: (this.bodyWidth * 2) / 3,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content3',
                        header: 'Content 3 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  Object.assign({ type: IgcDockManagerPaneType.contentPane, contentId: 'content_not_used_2', header: 'NOT USED' }, this.commonProps),
                ],
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content4',
                header: 'Content 4 Header',
                size: 290, // PIXELS
              },
              {
                type: IgcDockManagerPaneType.splitPane,
                orientation: IgcSplitPaneOrientation.horizontal,
                size: 240 + 10,
                panes: [
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: this.bodyWidth / 3,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content5',
                        header: 'Content 5 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: (this.bodyWidth * 2) / 3,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content6',
                        header: 'Content 6 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  Object.assign({ type: IgcDockManagerPaneType.contentPane, contentId: 'content_not_used_3', header: 'NOT USED' }, this.commonProps),
                ],
              },
              {
                type: IgcDockManagerPaneType.splitPane,
                orientation: IgcSplitPaneOrientation.horizontal,
                size: 240 + 10,
                panes: [
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: this.bodyWidth / 2,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content7',
                        header: 'Content 7 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  {
                    type: IgcDockManagerPaneType.splitPane,
                    orientation: IgcSplitPaneOrientation.vertical,
                    size: this.bodyWidth / 2,
                    panes: [
                      {
                        type: IgcDockManagerPaneType.contentPane,
                        contentId: 'content8',
                        header: 'Content 8 Header',
                        size: 240, // PIXELS
                      },
                    ],
                  },
                  Object.assign({ type: IgcDockManagerPaneType.contentPane, contentId: 'content_not_used_4', header: 'NOT USED' }, this.commonProps),
                ],
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content9',
                header: 'Content 9 Header',
                size: 290, // PIXELS
              },
              Object.assign({ type: IgcDockManagerPaneType.contentPane, contentId: 'content_not_used_1', header: 'NOT USED' }, this.commonProps),
            ],
          },
        ],
      },
      floatingPanes: [],
    };
    // UseFizedSize with DCH
    this.layout6 = {
      rootPane: {
        type: IgcDockManagerPaneType.splitPane,
        orientation: IgcSplitPaneOrientation.vertical,
        useFixedSize: true,
        panes: [
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.horizontal,
            useFixedSize: true,
            size: 300,
            panes: [
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content1",
                header: "Content Pane 1",
                size: 300
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content2",
                header: "Content Pane 2",
                size: 700
              },
            ]
          },
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.horizontal,
            useFixedSize: true,
            size: 500,
            panes: [
              {
                type: IgcDockManagerPaneType.documentHost,
                size: 508,
                rootPane: {
                  type: IgcDockManagerPaneType.splitPane,
                  orientation: IgcSplitPaneOrientation.horizontal,
                  useFixedSize: true,
                  allowEmpty: true,
                  panes: [
                    {
                      type: IgcDockManagerPaneType.tabGroupPane,
                      size: 300,
                      panes: [
                        {
                          type: IgcDockManagerPaneType.contentPane,
                          header: 'MainWindow.xaml',
                          contentId: 'content7',
                          documentOnly: true,
                          // allowMaximize: false,
                        },
                        {
                          type: IgcDockManagerPaneType.contentPane,
                          header: 'MainWindow.xaml.cs',
                          contentId: 'content9',
                          documentOnly: true,
                          allowFloating: false
                        }
                      ]
                    },
                    {
                      type: IgcDockManagerPaneType.contentPane,
                      header: 'App.xaml',
                      contentId: 'content8',
                      allowMaximize: true,
                      acceptsInnerDock: false,
                      size: 200
                    }
                  ]
                }
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content3",
                header: "Content Pane 3",
                size: 400
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content4",
                header: "Content Pane 4",
                size: 400
              }
            ]
          },
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.horizontal,
            // useFixedSize: true,
            size: 300,
            panes: [
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content5",
                header: "Content Pane 5",
                size: 500
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content6",
                header: "Content Pane 6",
                size: 800
              }
            ]
          }
        ]
      },
      floatingPanes: [],
    };
    // The layout used in 'useFixedSize' unit tests
    this.layout7 = {
      rootPane: {
        type: IgcDockManagerPaneType.splitPane,
        orientation: IgcSplitPaneOrientation.vertical,
        // useFixedSize: true,
        panes: [
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.horizontal,
            useFixedSize: true,
            panes: [
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content1",
                header: "Content Pane 1",
                size: 400
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content2",
                header: "Content Pane 2",
                size: 600
              },
            ]
          },
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.horizontal,
            panes: [
              {
                type: IgcDockManagerPaneType.tabGroupPane,
                size: 400,
                panes: [
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    contentId: "content3",
                    header: "Content Pane 3"
                  },
                  {
                    type: IgcDockManagerPaneType.contentPane,
                    contentId: "content4",
                    header: "Content Pane 4",
                  }
                ]
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: "content5",
                header: "Content Pane 5",
                size: 600
              }
            ]
          },
          {
            type: IgcDockManagerPaneType.contentPane,
            contentId: "content6",
            header: "Content Pane 6"
          }
        ]
      },
      floatingPanes: [{
          type: IgcDockManagerPaneType.splitPane,
          orientation: IgcSplitPaneOrientation.vertical,
          floatingHeight: 200,
          floatingWidth: 300,
          panes: [{
              type: IgcDockManagerPaneType.contentPane,
              contentId: "content7",
              header: "Content Pane 7"
            }]
        }]
    };
    // No floating panes collection
    this.layout8 = {
      rootPane: {
        type: IgcDockManagerPaneType.splitPane,
        orientation: IgcSplitPaneOrientation.horizontal,
        panes: [
          {
            type: IgcDockManagerPaneType.splitPane,
            orientation: IgcSplitPaneOrientation.vertical,
            panes: [
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content1',
                header: 'Content Pane 1'
              },
              {
                type: IgcDockManagerPaneType.contentPane,
                contentId: 'content2',
                header: 'Unpinned Pane 1',
                isPinned: false
              }
            ]
          },
        ]
      },
    };
    this.layout = this.layout1;
    this.logEnabled = false;
    this.hiddenPanes = [];
  }
  // private hideOnCloseCheckbox: HTMLInputElement;
  /*
  private hiddenPanesSelect: HTMLSelectElement;
  private savedLayout: string;

  private saveLayout() {
    this.savedLayout = JSON.stringify(this.dockManager.layout);
  }

  private loadLayout() {
    this.dockManager.layout = JSON.parse(this.savedLayout);
  }

  private setActivePane() {
    // this.dockManager.activePane = this.teamExplorerPane;
    this.dockManager.activePane = this.unpinnedToolboxPane;
  }

  private id = 100;
  private newId: string;

  private addPane() {
    this.newId = `content${this.id++}`;
    const newDiv = this.createElement(this.newId, 'input');
    this.dockManager.appendChild(newDiv);

    this.layout.floatingPanes[1].panes.push({
      type: IgcDockManagerPaneType.contentPane,
      header: 'NewPane',
      contentId: this.newId
    });

    this.dockManager.layout = { ...this.layout };
  }

  private addTab() {
    this.findElement(this.layout.rootPane, IgcDockManagerPaneType.tabGroupPane);

    this.newId = `content${this.id++}`;
    const newDiv = this.createElement(this.newId, 'button');
    this.dockManager.appendChild(newDiv);

    const tabGroupPane = this.foundElem[0] as IgcTabGroupPane;
    tabGroupPane.panes.push({
      type: IgcDockManagerPaneType.contentPane,
      header: 'NewTab',
      contentId: this.newId
    });

    this.dockManager.layout = { ...this.layout };
  }

  private disableContentPane() {
    this.findElement(this.layout.rootPane, IgcDockManagerPaneType.tabGroupPane);

    const tabGroupPane = this.foundElem[0] as IgcTabGroupPane;
    tabGroupPane.panes[0].disabled = true;
    this.dockManager.layout = { ...this.layout };
  }

  private toggleProximityDock() {
    this.dockManager.proximityDock = !this.dockManager.proximityDock;
  }

  private focusPane() {
    this.dockManager.focusPane('content12');
  }

  private foundElem: IgcDockManagerPane[] = [];
  private findElement(pane: IgcDockManagerPane, type: IgcDockManagerPaneType) {
    if (!pane) { return; }

    if (pane.type === type) {
      this.foundElem.push(pane);
    }

    if (pane.type === IgcDockManagerPaneType.tabGroupPane || pane.type === IgcDockManagerPaneType.splitPane) {
      for (const c of pane.panes) {
        this.findElement(c, type);
      }
    }

    if (pane.type === IgcDockManagerPaneType.documentHost) {
      this.findElement(pane.rootPane, type);
    }
  }

  private showPane() {
    const index = this.hiddenPanesSelect.selectedIndex;

    if (index >= 0) {
      this.hiddenPanes[index].hidden = false;
      this.hiddenPanes.splice(index, 1);
      this.hiddenPanes = [...this.hiddenPanes];
      this.dockManager.layout = { ...this.dockManager.layout };
    }
  }

  private showAllPanes() {
    if (this.hiddenPanes.length > 0) {
      for (const pane of this.hiddenPanes) {
        pane.hidden = false;
      }
      this.hiddenPanes = [];
      this.dockManager.layout = { ...this.dockManager.layout };
    }
  }

  private toggleInBoundaries() {
    this.dockManager.containedInBoundaries = !this.dockManager.containedInBoundaries;
  }

  // private toggleUseFixedSize() {
  //   this.dockManager.useFixedSize = !this.dockManager.useFixedSize;
  // }

  private createElement(content: string, typeOfElement: string): HTMLElement {
    const someContent = document.createTextNode(content);
    let elem: HTMLElement;
    switch (typeOfElement) {
      case ('button'):
        elem = document.createElement('button');
        elem.appendChild(someContent);
        break;
      case ('input'):
        elem = document.createElement('input');
        break;
    }

    const divContent = document.createElement('div');
    divContent.appendChild(elem ? elem : someContent);
    divContent.setAttribute('slot', content);
    divContent.setAttribute('style', 'width: 100%; height: 100%;');

    return divContent;
  }
  */
  handlePaneClose(event) {
    this.log(event);
    // if (this.hideOnCloseCheckbox.checked) {
    //   for (const pane of event.detail.panes) {
    //     pane.hidden = true;
    //     this.hiddenPanes.splice(0, 0, pane);
    //     this.hiddenPanes = [...this.hiddenPanes];
    //   }
    //   event.preventDefault();
    // }
    // const panes = event.detail.panes;
    // const confirmed = confirm(`Are you sure you want to close panes '${panes.map(p => p.header).join(', ')}'?`);
    // // event.detail.panes = [panes[0]];
    // if (confirmed) {
    //   for (const pane of panes) {
    //     const contentChild = this.dockManager.querySelector(`[slot=${pane.contentId}]`);
    //     this.dockManager.removeChild(contentChild);
    //   }
    // } else {
    //   event.preventDefault();
    // }
  }
  handlePaneScroll(event) {
    this.log(event);
    // // check if the pane content is scrolled to bottom
    // let scrolledToBottom = false;
    // const contentEl = event.detail.contentElement;
    // if (contentEl.scrollHeight - contentEl.scrollTop - contentEl.clientHeight < 1)
    // {
    //   scrolledToBottom = true;
    // }
    // this.log("Scrolled to bottom: " + scrolledToBottom);
  }
  handlePinnedToggle(event) {
    this.log(event);
    // if (event.detail.sourcePane.type === IgcDockManagerPaneType.contentPane) {
    //   event.detail.panes = [event.detail.sourcePane];
    // }
    // event.preventDefault();
  }
  handleActivePaneChanged(event) {
    this.log(event);
  }
  handleDragStart(event) {
    this.log(event);
    // event.preventDefault();
  }
  handleDragOver(event) {
    const args = event.detail;
    this.log(args.action);
    if (args.action.type === IgcPaneDragActionType.dockPane) {
      if (args.action.dockingIndicator.position === IgcDockingIndicatorPosition.left) {
        // args.isValid = false;
      }
    }
    else if (args.action.type === IgcPaneDragActionType.floatPane) {
      // args.action.height = Math.min(args.action.height, 500);
      // args.isValid = false;
    }
    else if (args.action.type === IgcPaneDragActionType.moveFloatingPane) {
      // if (args.action.newLocation.y < 0) {
      //   args.isValid = false;
      // }
    }
  }
  handleDragEnd(event) {
    this.log(event);
  }
  handleSplitterResizeStart(event) {
    this.log(event, Object.assign({}, event.detail));
    // event.preventDefault();
  }
  handleSplitterResizeEnd(event) {
    this.log(event, Object.assign({}, event.detail));
  }
  handleFloatingPaneResizeStart(event) {
    this.log(event, Object.assign({}, event.detail));
    // event.preventDefault();
  }
  handleFloatingPaneResizeMove(event) {
    this.log(event, Object.assign({}, event.detail));
  }
  handleFloatingPaneResizeEnd(event) {
    this.log(event, Object.assign({}, event.detail));
  }
  handleLayoutChange(event) {
    this.log(event);
  }
  // private getCustomResourceStrings(): IgcDockManagerResourceStrings {
  //   const customResourceStrings: IgcDockManagerResourceStrings = {
  //     close: '[Custom]Close',
  //     pin: '[Custom]Pin',
  //     unpin: '[Custom]Unpin',
  //     maximize: '[Custom]Maximize',
  //     minimize: '[Custom]Minimize',
  //     moreOptions: '[Custom]More options'
  //   };
  //   return customResourceStrings;
  // }
  log(message, ...optionalParams) {
    if (this.logEnabled) {
      console.log(message, optionalParams);
    }
  }
  render() {
    return (h(Host, null, h("igc-dockmanager", { layout: this.layout, onPaneClose: this.handlePaneClose.bind(this), onPaneScroll: this.handlePaneScroll.bind(this), onPanePinnedToggle: this.handlePinnedToggle.bind(this), onActivePaneChanged: this.handleActivePaneChanged.bind(this), onPaneDragStart: this.handleDragStart.bind(this), onPaneDragOver: this.handleDragOver.bind(this), onPaneDragEnd: this.handleDragEnd.bind(this), onSplitterResizeStart: this.handleSplitterResizeStart.bind(this), onSplitterResizeEnd: this.handleSplitterResizeEnd.bind(this), onFloatingPaneResizeStart: this.handleFloatingPaneResizeStart.bind(this), onFloatingPaneResizeMove: this.handleFloatingPaneResizeMove.bind(this), onFloatingPaneResizeEnd: this.handleFloatingPaneResizeEnd.bind(this), onLayoutChange: this.handleLayoutChange.bind(this),
      // resourceStrings={this.getCustomResourceStrings()}
      ref: el => this.dockManager = el,
      // allowFloatingPanesResize={false}
      showHeaderIconOnHover: 'closeOnly' }, h("div", { slot: "header1" }, h("span", { style: { color: 'red' } }, "Solution Explorer"), h("button", null, "H")), h("div", { slot: "tabHeader1" }, h("span", { style: { color: 'orange' } }, "Solution Explorer"), h("button", null, "T")), h("div", { slot: "unpinnedHeader1" }, h("span", { style: { color: 'blue' } }, "Solution Explorer"), h("button", null, "U")), h("div", { slot: "toolboxHeader" }, h("span", null, "[U] Toolbox")), h("div", { slot: "teamExplorerHeader" }, h("span", null, "[U] Team Explorer")), h("button", { style: { background: 'pink' }, slot: "tabHeaderCloseButton" }, "Y"), h("div", { slot: "content1" }, "Content 1"), h("div", { slot: "content2" }, "Content 2"), h("div", { slot: "content3" }, "Content 3"), h("div", { slot: "content4" }, "Content 4"), h("div", { slot: "content5" }, "Content 5"), h("div", { slot: "content6" }, "Content 6"), h("div", { slot: "content7" }, "Content 7"), h("div", { slot: "content8" }, "Content 8"), h("div", { slot: "content9" }, "Content 9"), h("div", { slot: "content_not_used_1" }), h("div", { slot: "content_not_used_2" }), h("div", { slot: "content_not_used_3" }), h("div", { slot: "content_not_used_4" }))));
  }
  static get is() { return "sample-component"; }
  static get encapsulation() { return "scoped"; }
  static get originalStyleUrls() {
    return {
      "$": ["sample-component.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sample-component.css"]
    };
  }
  static get properties() {
    return {
      "hiddenPanes": {
        "type": "unknown",
        "mutable": true,
        "complexType": {
          "original": "IgcContentPane[]",
          "resolved": "IgcContentPane[]",
          "references": {
            "IgcContentPane": {
              "location": "import",
              "path": "../dockmanager/dockmanager.public-interfaces",
              "id": "src/components/dockmanager/dockmanager.public-interfaces.ts::IgcContentPane"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "defaultValue": "[]"
      }
    };
  }
}
//# sourceMappingURL=sample-component.js.map
